@@ -530,6 +530,14 @@ def test_time_local_ns():
     del ip.user_ns["myvar"]
 
 
+def test_time_microseconds_display():
+    """Ensure ASCII is used when necessary"""
+    with mock.patch("sys.stdout", io.TextIOWrapper(StringIO(), encoding="utf-8")):
+        assert execution._format_time(0.000001) == "1 \u03bcs"
+    with mock.patch("sys.stdout", io.TextIOWrapper(StringIO(), encoding="ascii")):
+        assert execution._format_time(0.000001) == "1 us"
+
+
 # Test %%capture magic. Added to test issue #13926
 def test_capture():
     ip = get_ipython()
@@ -715,6 +723,7 @@ def doctest_precision():
     Out[5]: '3.141593e+00'
     """
 
+
 def test_debug_magic():
     """Test debugging a small code with %debug
 
@@ -727,6 +736,22 @@ def test_debug_magic():
     In [2]:
     """
 
+
+def test_debug_magic_locals():
+    """Test debugging a small code with %debug with locals
+
+    In [1]: with PdbTestInput(['c']):
+       ...:     def fun():
+       ...:         res = 1
+       ...:         %debug print(res)
+       ...:     fun()
+       ...:
+    ...
+    ipdb> c
+    1
+    In [2]:
+    """
+
 def test_psearch():
     with tt.AssertPrints("dict.fromkeys"):
         _ip.run_cell("dict.fr*?")
